riverpod_swiss_knife library

A Swiss Army knife for Riverpod.

Mixins

UpdateNotifierMixin<T>
A mixin that adds an update method, meant to be used on Notifier

Extensions

AddDisposeDelayRef on Ref
Extension on Ref to add a dispose delay.
CacheRef on Ref
Extension on Ref to cache the provider for a specific duration.
DebounceForRef on Ref
Extension on Ref to debounce the provider for a specific duration.
InvalidatePeriodicallyRef on Ref
Extension on Ref to periodically invalidate a provider.
RefInvalidateSelfAfter on Ref
Extension on Ref to invalidate itself after a specific duration.
RefOnRepeat on Ref
Extension on Ref to do something repeatedly at a specific interval.
RefRun on Ref
Extension on Ref to run an asynchronous provider, and get its value.
RefTimeout on Ref
Extension on Ref to do something after a specific duration.

Exceptions / Errors

RiverpodCancelException
thrown when an operation is canceled: should be quite low in your logs level, and should be ignored in your business logic